@@ -170,7 +170,7 @@ class ConvParser(Parser):
                                                 ia_dimension_shape, oa_dimension_shape,
                                                 node_mapping)
 
-        node_obj = LayerNode(self.node_id, node_attrs, node_name=self.node.name)
+        node_obj = LayerNode(self.node_id, node_attrs, node_name=self.node.name, type=self.node.op_type.lower())
         
         logger.info(f"Parsed Conv node {self.node.name}")
 
